package com.ruoyi.inventory.service;

import java.util.List;
import com.ruoyi.inventory.domain.TbInventoryDetail;

/**
 * 资产盘点明细Service接口
 * 
 * @author ydl
 * @date 2023-06-01
 */
public interface ITbInventoryDetailService 
{
    /**
     * 查询资产盘点明细
     * 
     * @param id 资产盘点明细主键
     * @return 资产盘点明细
     */
    public TbInventoryDetail selectTbInventoryDetailById(Long id);

    /**
     * 查询资产盘点明细列表
     * 
     * @param tbInventoryDetail 资产盘点明细
     * @return 资产盘点明细集合
     */
    public List<TbInventoryDetail> selectTbInventoryDetailList(TbInventoryDetail tbInventoryDetail);

    /**
     * 新增资产盘点明细
     * 
     * @param tbInventoryDetail 资产盘点明细
     * @return 结果
     */
    public int insertTbInventoryDetail(TbInventoryDetail tbInventoryDetail);

    /**
     * 修改资产盘点明细
     * 
     * @param tbInventoryDetail 资产盘点明细
     * @return 结果
     */
    public int updateTbInventoryDetail(TbInventoryDetail tbInventoryDetail);

    /**
     * 批量删除资产盘点明细
     * 
     * @param ids 需要删除的资产盘点明细主键集合
     * @return 结果
     */
    public int deleteTbInventoryDetailByIds(Long[] ids);

    /**
     * 删除资产盘点明细信息
     * 
     * @param id 资产盘点明细主键
     * @return 结果
     */
    public int deleteTbInventoryDetailById(Long id);
}
